@@ -3,7 +3,9 @@
 # Copy the test study in a temporary folder
 
 path <- tempdir()
-sourcedir <- system.file("testdata", package = "antaresRead")
+sourcedir <- system.file("inst/testdata", package = "antaresRead")
+if(sourcedir == ""){ sourcedir <- system.file("testdata", package = "antaresRead")}
+
 
 # Hack: For some unknown reason, this script is executed at some point of
 # the R CMD CHECK before package is correctly installed and tests actually run. 
@@ -24,7 +26,7 @@ if (sourcedir != "") {
         writeAntaresH5(path = path, 
                        misc = TRUE, thermalAvailabilities = TRUE,
                        hydroStorage = TRUE, hydroStorageMaxPower = TRUE, reserve = TRUE,
-                       linkCapacity = TRUE,mustRun = TRUE, thermalModulation = TRUE)
+                       linkCapacity = TRUE,mustRun = TRUE, thermalModulation = TRUE, overwrite=TRUE)
       })
     })
     
